@@ -1,11 +1,11 @@
 package Gzip::Faster;
 require Exporter;
 @ISA = qw(Exporter);
-@EXPORT = qw/gzip gunzip gzip_file gunzip_file/;
+@EXPORT = qw/gzip gunzip gzip_file gunzip_file gzip_to_file/;
 use warnings;
 use strict;
 use Carp;
-our $VERSION = 0.07;
+our $VERSION = 0.08;
 require XSLoader;
 XSLoader::load ('Gzip::Faster', $VERSION);
 
@@ -15,6 +15,7 @@ sub gzip_file
     open my $in, "<:raw", $file or croak "Error opening '$file': $!";
     local $/;
     my $plain = <$in>;
+    close $in or die "Error closing '$file': $!";
     return gzip ($plain);
 }
 
@@ -24,7 +25,15 @@ sub gunzip_file
     open my $in, "<:raw", $file or croak "Error opening '$file': $!";
     local $/;
     my $zipped = <$in>;
+    close $in or die "Error closing '$file': $!";
     return gunzip ($zipped);
 }
 
+sub gzip_to_file
+{
+    my ($plain, $file) = @_;
+    open my $in, ">:raw", $file or croak "Error opening '$file': $!";
+    print $in gzip ($plain);
+}
+
 1;
